#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2019 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o nounset
set -o errexit
set -o pipefail

if [[ "$EXECUTION_MODE" == "offline-deployment" && "$PROVISIONER_TYPE" == "heat" ]]; then
  echo "Info  : Offline deployments on cloud instances is not currently supported!"
  exit 0
fi

if [[ "$EXECUTION_MODE" == "offline-deployment" ]]; then
  ENGINE_ROOT_DIR="/opt/engine/offline/git/engine"
  PDF="file:///opt/engine/offline/git/hwconfig/pods/nordix-vpod1-pdf.yml"
  IDF="file:///opt/engine/offline/git/hwconfig/pods/nordix-vpod1-idf.yml"
else
  ENGINE_ROOT_DIR="$WORKSPACE"
  PDF="https://gerrit.nordix.org/gitweb?p=infra/hwconfig.git;a=blob_plain;f=pods/nordix-vpod1-pdf.yml"
  IDF="https://gerrit.nordix.org/gitweb?p=infra/hwconfig.git;a=blob_plain;f=pods/nordix-vpod1-idf.yml"
fi

/bin/cp -f $OPENRC_FILE /tmp/openrc
cd "$ENGINE_ROOT_DIR/engine"
./deploy.sh -d kubespray -s k8-calico-nofeature -b "file://$ENGINE_ROOT_DIR/engine/inventory/group_vars/all/sdf.yaml" \
    -r $PROVISIONER_TYPE -p $PDF -i $IDF -u /tmp/openrc \
    -e "file://$ENGINE_ROOT_DIR/engine/provisioner/heat/playbooks/roles/bootstrap-hwconfig/files/$HEAT_ENVIRONMENT_FILENAME"
